==> bigdata-common-0.0.217-sources.jar: cn/com/duiba/bigdata/common/biz/constant/HologresTableKeys.java <==
package cn.com.duiba.bigdata.common.biz.constant;

public class HologresTableKeys {

    //hologres 实时库
    //兑吧访问日志明细表
    public static final String DUIBA_ACCESS_LOG_DETAIL_MONTH = "duiba_access_log_detail_month";

    //兑吧曝光日志明细表
    public static final String DUIBA_EXPOSURE_LOG_DETAIL_MONTH = "duiba_exposure_log_detail_month";

    //兑吧内部日志明细表
    //保存一个月数据
    public static final String DUIBA_INNER_LOG_DETAIL_MONTH = "duiba_inner_log_detail_month";

    //保存一天数据
    public static final String DUIBA_INNER_LOG_DETAIL_DAY = "duiba_inner_log_detail_day";

    //访问日志实验平台数据
    public static final String LAB_ACCESS_LOG_DETAIL_DAY = "lab_access_log_detail_day";

    //内部日志实验平台数据
    public static final String LAB_INNER_LOG_DETAIL_DAY = "lab_inner_log_detail_day";

    //adx日志实验平台数据
    public static final String LAB_ADX_LOG_DETAIL_DAY = "lab_adx_log_detail_day";

    //算法日志保存一个月数据
    public static final String ALG_LOG_DETAIL_MONTH = "alg_log_detail_month";

    //adx日志分钟聚合数据保存一天
    public static final String ADX_LOG_SUM_DAY = "adx_log_sum_day";

    //adx竞价请求日志分钟聚合
    public static final String ADX_BID_REQUEST_LOG_MINUTE = "adx_bid_request_log_minute";

    //adx预估指标聚合
    public static final String ADX_ALG_DETAIL_MINUTE_MONTH = "adx_alg_detail_minute_month";

    //兑吧活动埋点日志聚合
    public static final String DUIBA_CLICK_LOG_DETAIL_MONTH = "duiba_click_log_detail_month";

    //ext01日志
    public static final String DUIBA_EXT01_LOG_DETAIL_DAY = "duiba_ext01_log_detail_day";

    //ext02日志
    public static final String DUIBA_EXT02_LOG_DETAIL_DAY = "duiba_ext02_log_detail_day";

    //程序化采量平台表
    public static final String DUIBA_PROGRAM_PRODUCT_PLATFORM_MONTH = "duiba_program_product_platform_month";

    //hologres 离线汇总库
    //访问日志天粒度汇总数据
    public static final String DUIBA_ACCESS_LOG_OFFLINE = "duiba_access_log_offline";

    //内部日志天粒度汇总数据
    public static final String DUIBA_INNER_LOG_OFFLINE = "duiba_inner_log_offline";

    //竞价日志半小时粒度窗口函数汇总数据
    public static final String TUIA_ADVERT_BID_OFFLINE = "tuia_advert_bid_offline";

    //过滤日志半小时粒度窗口函数汇总数据
    public static final String ADVERT_FILTER_REASON_OFFLINE = "advert_filter_reason_offline";

    //ADX过滤日志半小时粒度窗口函数汇总数据
    public static final String ADX_FILTER_REASON_OFFLINE = "adx_filter_reason_offline";

    //广告配置过滤日志半小时粒度窗口函数汇总数据
    public static final String ADVERT_FILTER_CONFIG_OFFLINE = "advert_filter_config_offline";

    //媒体线流量指标统计增量表
    public static final String TB_APP_LINE_DI = "tb_app_line_di";

    //dmp上传人群包
    public static final String DMP_UPLOAD_CROWD = "dmp_upload_crowd";

    //hologres 兑吧直播库
    //兑吧直播-邀请预约到场日志
    public static final String DUIBA_LIVE_INVITATION_LOG = "duiba_live_invitation_log";

    //兑吧直播-观看互动日志
    public static final String DUIBA_LIVE_WATCH_LOG = "duiba_live_watch_log";

    //兑吧直播-商品预约点击日志
    public static final String DUIBA_LIVE_GOODS_APPOINTMENT_LOG = "duiba_live_goods_appointment_log";

    //兑吧直播-红包领取日志
    public static final String DUIBA_LIVE_RED_PACKET_LOG = "duiba_live_red_packet_log";

    //兑吧直播-手气王红包助力日志
    public static final String DUIBA_LIVE_LUCK_RED_PACKET_LOG = "duiba_live_luck_red_packet_log";

    //兑吧直播-分享日志
    public static final String DUIBA_LIVE_SHARE_LOG = "duiba_live_share_log";

    //兑吧直播-评论日志
    public static final String DUIBA_LIVE_COMMON_LOG = "duiba_live_comment_log";

    //兑吧直播-点赞日志
    public static final String DUIBA_LIVE_GIVE_LIKE_LOG = "duiba_live_give_like_log";


    //兑吧直播-关注日志
    public static final String DUIBA_LIVE_ATTENTION_LOG = "duiba_live_attention_log";


    //兑吧直播-互动商品
    public static final String DUIBA_LIVE_ITEM_LOG = "duiba_live_item_log";


    //兑吧直播-互动商品-办卡
    public static final String DUIBA_LIVE_ITEM_CARD_LOG = "duiba_live_item_card_log";


    //hologres 兑吧活动库
    public static final String DUIBA_SAAS_INNER_LOG = "duiba_saas_inner_log";


    // 兑吧活动埋点
    //兑吧活动领奖
    public static final String DUIBA_SAAS_ACTIVITY_PRIZE_DETAIL_DAY = "duiba_saas_activity_prize_detail_day";

    //兑吧活动参与
    public static final String DUIBA_SAAS_ACTIVITY_JOIN_DETAIL_DAY = "duiba_saas_activity_join_detail_day";

    //兑吧活动访问
    public static final String DUIBA_SAAS_ACTIVITY_VISIT_DETAIL_DAY = "duiba_saas_activity_visit_detail_day";

    //兑吧活动中奖
    public static final String DUIBA_SAAS_ACTIVITY_WIN_DETAIL_DAY = "duiba_saas_activity_win_detail_day";

    //兑吧前端点击
    public static final String DUIBA_SAAS_FRONTEND_EVENT_CLICK_DETAIL_DAY = "duiba_saas_frontend_event_click_detail_day";

    //兑吧前端退出
    public static final String DUIBA_SAAS_FRONTEND_EVENT_EXIT_DETAIL_DAY = "duiba_saas_frontend_event_exit_detail_day";

    //兑吧前端曝光
    public static final String DUIBA_SAAS_FRONTEND_EVENT_VIEW_DETAIL_DAY = "duiba_saas_frontend_event_view_detail_day";

    //兑吧游戏结束
    public static final String DUIBA_SAAS_GAME_FINISH_DETAIL_DAY = "duiba_saas_game_finish_detail_day";

    //兑吧积分商城-每天统计数据-离线数据
    public static final String DM_DEVELOPER_DETAIL_DI = "dm_developer_detail_di";

    //兑吧积分商城-商品详情页-每天统计数据-离线数据
    public static final String DM_ITEM_DETAIL_DI = "dm_item_detail_di";

    //兑吧积分商城-活动-每天统计数据-离线数据
    public static final String DM_ACTIVITY_DETAIL_DI = "dm_activity_detail_di";



}

==> bigdata-common-0.1.56-sources.jar: cn/com/duiba/bigdata/common/biz/constant/HologresTableKeys.java <==
package cn.com.duiba.bigdata.common.biz.constant;

public class HologresTableKeys {

    //hologres 实时库
    //兑吧访问日志明细表
    public static final String DUIBA_ACCESS_LOG_DETAIL_MONTH = "duiba_access_log_detail_month";

    //兑吧曝光日志明细表
    public static final String DUIBA_EXPOSURE_LOG_DETAIL_MONTH = "duiba_exposure_log_detail_month";

    //兑吧内部日志明细表
    //保存一个月数据
    public static final String DUIBA_INNER_LOG_DETAIL_MONTH = "duiba_inner_log_detail_month";

    //保存一天数据
    public static final String DUIBA_INNER_LOG_DETAIL_DAY = "duiba_inner_log_detail_day";

    //访问日志实验平台数据
    public static final String LAB_ACCESS_LOG_DETAIL_DAY = "lab_access_log_detail_day";

    //内部日志实验平台数据
    public static final String LAB_INNER_LOG_DETAIL_DAY = "lab_inner_log_detail_day";

    //adx日志实验平台数据
    public static final String LAB_ADX_LOG_DETAIL_DAY = "lab_adx_log_detail_day";

    //算法日志保存一个月数据
    public static final String ALG_LOG_DETAIL_MONTH = "alg_log_detail_month";

    //adx日志分钟聚合数据保存一天
    public static final String ADX_LOG_SUM_DAY = "adx_log_sum_day";

    //adx竞价请求日志分钟聚合
    public static final String ADX_BID_REQUEST_LOG_MINUTE = "adx_bid_request_log_minute";

    //adx预估指标聚合
    public static final String ADX_ALG_DETAIL_MINUTE_MONTH = "adx_alg_detail_minute_month";

    //兑吧活动埋点日志聚合
    public static final String DUIBA_CLICK_LOG_DETAIL_MONTH = "duiba_click_log_detail_month";

    //ext01日志
    public static final String DUIBA_EXT01_LOG_DETAIL_DAY = "duiba_ext01_log_detail_day";

    //ext02日志
    public static final String DUIBA_EXT02_LOG_DETAIL_DAY = "duiba_ext02_log_detail_day";

    //程序化采量平台表
    public static final String DUIBA_PROGRAM_PRODUCT_PLATFORM_MONTH = "duiba_program_product_platform_month";

    //hologres 离线汇总库
    //访问日志天粒度汇总数据
    public static final String DUIBA_ACCESS_LOG_OFFLINE = "duiba_access_log_offline";

    //内部日志天粒度汇总数据
    public static final String DUIBA_INNER_LOG_OFFLINE = "duiba_inner_log_offline";

    //竞价日志半小时粒度窗口函数汇总数据
    public static final String TUIA_ADVERT_BID_OFFLINE = "tuia_advert_bid_offline";

    //过滤日志半小时粒度窗口函数汇总数据
    public static final String ADVERT_FILTER_REASON_OFFLINE = "advert_filter_reason_offline";

    //ADX过滤日志半小时粒度窗口函数汇总数据
    public static final String ADX_FILTER_REASON_OFFLINE = "adx_filter_reason_offline";

    //广告配置过滤日志半小时粒度窗口函数汇总数据
    public static final String ADVERT_FILTER_CONFIG_OFFLINE = "advert_filter_config_offline";

    //媒体线流量指标统计增量表
    public static final String TB_APP_LINE_DI = "tb_app_line_di";

    //dmp上传人群包
    public static final String DMP_UPLOAD_CROWD = "dmp_upload_crowd";

    //hologres 兑吧直播库
    //兑吧直播-邀请预约到场日志
    public static final String DUIBA_LIVE_INVITATION_LOG = "duiba_live_invitation_log";

    //兑吧直播-观看互动日志
    public static final String DUIBA_LIVE_WATCH_LOG = "duiba_live_watch_log";

    //兑吧直播-商品预约点击日志
    public static final String DUIBA_LIVE_GOODS_APPOINTMENT_LOG = "duiba_live_goods_appointment_log";

    //兑吧直播-红包领取日志
    public static final String DUIBA_LIVE_RED_PACKET_LOG = "duiba_live_red_packet_log";

    //兑吧直播-手气王红包助力日志
    public static final String DUIBA_LIVE_LUCK_RED_PACKET_LOG = "duiba_live_luck_red_packet_log";

    //兑吧直播-分享日志
    public static final String DUIBA_LIVE_SHARE_LOG = "duiba_live_share_log";

    //兑吧直播-评论日志
    public static final String DUIBA_LIVE_COMMON_LOG = "duiba_live_comment_log";

    //兑吧直播-点赞日志
    public static final String DUIBA_LIVE_GIVE_LIKE_LOG = "duiba_live_give_like_log";


    //兑吧直播-关注日志
    public static final String DUIBA_LIVE_ATTENTION_LOG = "duiba_live_attention_log";


    //兑吧直播-互动商品
    public static final String DUIBA_LIVE_ITEM_LOG = "duiba_live_item_log";


    //兑吧直播-互动商品-办卡
    public static final String DUIBA_LIVE_ITEM_CARD_LOG = "duiba_live_item_card_log";


    //hologres 兑吧活动库
    public static final String DUIBA_SAAS_INNER_LOG = "duiba_saas_inner_log";


    // 兑吧活动埋点
    //兑吧活动领奖
    public static final String DUIBA_SAAS_ACTIVITY_PRIZE_DETAIL_DAY = "duiba_saas_activity_prize_detail_day";

    //兑吧活动参与
    public static final String DUIBA_SAAS_ACTIVITY_JOIN_DETAIL_DAY = "duiba_saas_activity_join_detail_day";

    //兑吧活动访问
    public static final String DUIBA_SAAS_ACTIVITY_VISIT_DETAIL_DAY = "duiba_saas_activity_visit_detail_day";

    //兑吧活动中奖
    public static final String DUIBA_SAAS_ACTIVITY_WIN_DETAIL_DAY = "duiba_saas_activity_win_detail_day";

    //兑吧前端点击
    public static final String DUIBA_SAAS_FRONTEND_EVENT_CLICK_DETAIL_DAY = "duiba_saas_frontend_event_click_detail_day";

    //兑吧前端退出
    public static final String DUIBA_SAAS_FRONTEND_EVENT_EXIT_DETAIL_DAY = "duiba_saas_frontend_event_exit_detail_day";

    //兑吧前端曝光
    public static final String DUIBA_SAAS_FRONTEND_EVENT_VIEW_DETAIL_DAY = "duiba_saas_frontend_event_view_detail_day";

    //兑吧游戏结束
    public static final String DUIBA_SAAS_GAME_FINISH_DETAIL_DAY = "duiba_saas_game_finish_detail_day";

    //兑吧积分商城-每天统计数据-离线数据
    public static final String DM_DEVELOPER_DETAIL_DI = "dm_developer_detail_di";

    //兑吧积分商城-商品详情页-每天统计数据-离线数据
    public static final String DM_ITEM_DETAIL_DI = "dm_item_detail_di";

    //兑吧积分商城-活动-每天统计数据-离线数据
    public static final String DM_ACTIVITY_DETAIL_DI = "dm_activity_detail_di";

    //推啊广告-活动明细表（实时数据，保存一个月）
    public static final String TUIA_ACTIVITY_LOG_DETAIL_MONTH = "tuia_activity_log_detail_month";

    //推啊广告-广告明细表（实时数据，保存一个月）
    public static final String TUIA_ADVERT_LOG_DETAIL_MONTH = "tuia_advert_log_detail_month";

    //推啊广告-ext01明细表（实时数据，保存一个月）
    public static final String TUIA_EXT01_LOG_DETAIL_MONTH = "tuia_ext01_log_detail_month";

    //推啊广告-ext02明细表（实时数据，保存一个月）
    public static final String TUIA_EXT02_LOG_DETAIL_MONTH = "tuia_ext02_log_detail_month";

    //adx业务-dsp请求分钟汇总数据（实时数据，保存一个月）
    public static final String ADX_DSP_REQUEST_MINUTE = "adx_dsp_request_minute";

    //adx业务-adx请求分钟汇总数据（实时数据，保存一个月）
    public static final String ADX_BID_REQUEST_MINUTE = "adx_bid_request_minute";

    //adx业务-adx明细数据表（实时数据，保存一个月）
    public static final String ADX_LOG_DETAIL_MONTH = "adx_log_detail_month";




}
